==> react-native-reanimated-v1-1.13.5.tgz: package/README.md <==
# Last publish from `react-native-reanimated` into `v1` branch

<p align="center">
  <h1 align="center">React Native Reanimated</h1>
  <h3 align="center">React Native's Animated library reimplemented</h3>
</p>

React Native Reanimated provides a more comprehensive,
low level abstraction for the Animated library API to be built
on top of and hence allow for much greater flexibility especially when it
comes to gesture based interactions.

## Installation

Check [getting started](https://software-mansion.github.io/react-native-reanimated/getting-started.html) section of our docs for the detailed installation instructions.

## Documentation

Check out our dedicated documentation page for info about this library, API reference and more: [https://software-mansion.github.io/react-native-reanimated](https://software-mansion.github.io/react-native-reanimated)

## Examples

The source code for the example (showcase) app is under the [`Example/`](https://github.com/software-mansion/react-native-reanimated/blob/master/Example/) directory.
If you want to play with the API but don't feel like trying it on a real app, you can run the example project. Clone the repo, go to the Example/ folder and run:

```
yarn install
```

### Running on iOS

Before running the app, install the cocoapods dependencies:

```
cd ios && pod install && cd ..
```

Now, you can start the app:

```
react-native run-ios
```

### Running on Android

Run the react native's cli command:

```
react-native run-android
```

**Important:** You will need to have an Android or iOS device or emulator connected as well as react-native-cli package installed globally.

## License

Reanimated library is licensed under [The MIT License](LICENSE).

## Credits

This project is supported by amazing people from [Expo.io](https://expo.io) and [Software Mansion](https://swmansion.com)

[![expo](https://avatars2.githubusercontent.com/u/12504344?v=3&s=100 'Expo.io')](https://expo.io)
[![swm](https://avatars0.githubusercontent.com/u/56880679?v=3&s=100 'Software Mansion')](https://swmansion.com)

==> react-native-reanimated-1.7.0.tgz: package/README.md <==
<p align="center">
  <h1 align="center">React Native Reanimated</h1>
  <h3 align="center">React Native's Animated library reimplemented</h3>
</p>

React Native Reanimated provides a more comprehensive,
low level abstraction for the Animated library API to be built
on top of and hence allow for much greater flexibility especially when it
comes to gesture based interactions.

## Installation

Check [getting started](https://software-mansion.github.io/react-native-reanimated/getting-started.html) section of our docs for the detailed installation instructions.

## Documentation

Check out our dedicated documentation page for info about this library, API reference and more: [https://software-mansion.github.io/react-native-reanimated](https://software-mansion.github.io/react-native-reanimated)

## Examples

The source code for the example (showcase) app is under the [`Example/`](https://github.com/software-mansion/react-native-reanimated/blob/master/Example/) directory.
If you want to play with the API but don't feel like trying it on a real app, you can run the example project. Clone the repo, go to the Example/ folder and run:

```
yarn install
```

Then run `react-native run-android` or `react-native run-ios` (depending on which platform you want to run the example app on).

You will need to have an Android or iOS device or emulator connected as well as react-native-cli package installed globally.

## License

Reanimated library is licensed under [The MIT License](LICENSE).

## Credits

This project is supported by amazing people from [Expo.io](https://expo.io) and [Software Mansion](https://swmansion.com)

[![expo](https://avatars2.githubusercontent.com/u/12504344?v=3&s=100 'Expo.io')](https://expo.io)
[![swm](https://avatars1.githubusercontent.com/u/6952717?v=3&s=100 'Software Mansion')](https://swmansion.com)
